@@ -1,4 +1,5 @@
-from typing import Union
+from enum import Enum, auto
+from typing import List, Union
 import traitlets
 import ipywidgets as ipw
 import requests
@@ -17,6 +18,7 @@ from optimade_client.logger import LOGGER
 from optimade_client.subwidgets import (
     FilterTabs,
     ResultsPageChooser,
+    SortSelector,
     StructureDropdown,
 )
 from optimade_client.utils import (
@@ -25,11 +27,42 @@ from optimade_client.utils import (
     handle_errors,
     ordered_query_url,
     perform_optimade_query,
+    get_sortable_fields,
     SESSION,
     TIMEOUT_SECONDS,
 )
 
 
+class QueryFilterWidgetOrder(Enum):
+    """Order of filter query widget parts"""
+
+    filter_header = auto()
+    filters = auto()
+    query_button = auto()
+    structures_header = auto()
+    structure_drop = auto()
+    sort_selector = auto()
+    error_or_status_messages = auto()
+    structure_page_chooser = auto()
+
+    @classmethod
+    def default_order(
+        cls, as_str: bool = True
+    ) -> List[Union[str, "QueryFilterWidgetOrder"]]:
+        """Get the default order of filter query widget parts"""
+        default_order = [
+            cls.filter_header,
+            cls.filters,
+            cls.query_button,
+            cls.structures_header,
+            cls.sort_selector,
+            cls.structure_page_chooser,
+            cls.structure_drop,
+            cls.error_or_status_messages,
+        ]
+        return [_.name for _ in default_order] if as_str else default_order
+
+
 class OptimadeQueryFilterWidget(  # pylint: disable=too-many-instance-attributes
     ipw.VBox
 ):
@@ -49,6 +82,7 @@ class OptimadeQueryFilterWidget(  # pylint: disable=too-many-instance-attributes
         result_limit: int = None,
         button_style: Union[ButtonStyle, str] = None,
         embedded: bool = False,
+        subparts_order: List[str] = None,
         **kwargs,
     ):
         self.page_limit = result_limit if result_limit else 10
@@ -65,6 +99,10 @@ class OptimadeQueryFilterWidget(  # pylint: disable=too-many-instance-attributes
         else:
             button_style = ButtonStyle.PRIMARY
 
+        subparts_order = subparts_order or QueryFilterWidgetOrder.default_order(
+            as_str=True
+        )
+
         self.offset = 0
         self.number = 1
         self._data_available = None
@@ -92,6 +130,11 @@ class OptimadeQueryFilterWidget(  # pylint: disable=too-many-instance-attributes
         self.structures_header = ipw.HTML(
             '<h4 style="margin-bottom:0px;padding:0px;">Results</h4>'
         )
+
+        self.sort_selector = SortSelector(disabled=True)
+        self.sorting = self.sort_selector.value
+        self.sort_selector.observe(self._sort, names="value")
+
         self.structure_drop = StructureDropdown(disabled=True)
         self.structure_drop.observe(self._on_structure_select, names="value")
         self.error_or_status_messages = ipw.HTML("")
@@ -101,16 +144,15 @@ class OptimadeQueryFilterWidget(  # pylint: disable=too-many-instance-attributes
             self._get_more_results, names=["page_link", "page_offset", "page_number"]
         )
 
+        for subpart in subparts_order:
+            if not hasattr(self, subpart):
+                raise ValueError(
+                    f"Wrongly specified subpart_order: {subpart!r}. Available subparts "
+                    f"(and default order): {QueryFilterWidgetOrder.default_order(as_str=True)}"
+                )
+
         super().__init__(
-            children=[
-                self.filter_header,
-                self.filters,
-                self.query_button,
-                self.structures_header,
-                self.structure_drop,
-                self.error_or_status_messages,
-                self.structure_page_chooser,
-            ],
+            children=[getattr(self, _) for _ in subparts_order],
             layout=ipw.Layout(width="auto", height="auto"),
             **kwargs,
         )
@@ -148,6 +190,9 @@ class OptimadeQueryFilterWidget(  # pylint: disable=too-many-instance-attributes
                 self.query_button.description = "Search"
                 self.query_button.icon = "search"
                 self.query_button.tooltip = "Search"
+                self.sort_selector.valid_fields = sorted(
+                    get_sortable_fields(self.database[1].base_url)
+                )
                 self.unfreeze()
 
     def _on_structure_select(self, change):
@@ -220,12 +265,23 @@ class OptimadeQueryFilterWidget(  # pylint: disable=too-many-instance-attributes
             self.query_button.tooltip = "Search"
             self.unfreeze()
 
+    def _sort(self, change: dict) -> None:
+        """"Perform new query with new sorting"""
+        sort = change["new"]
+        if not sort:
+            raise ValueError(
+                f"The sort parameter could not be determined (sort={sort!r})."
+            )
+        self.sorting = sort
+        self.retrieve_data({})
+
     def freeze(self):
         """Disable widget"""
         self.query_button.disabled = True
         self.filters.freeze()
         self.structure_drop.freeze()
         self.structure_page_chooser.freeze()
+        self.sort_selector.freeze()
 
     def unfreeze(self):
         """Activate widget (in its current state)"""
@@ -233,6 +289,7 @@ class OptimadeQueryFilterWidget(  # pylint: disable=too-many-instance-attributes
         self.filters.unfreeze()
         self.structure_drop.unfreeze()
         self.structure_page_chooser.unfreeze()
+        self.sort_selector.unfreeze()
 
     def reset(self):
         """Reset widget"""
@@ -244,6 +301,7 @@ class OptimadeQueryFilterWidget(  # pylint: disable=too-many-instance-attributes
             self.filters.reset()
             self.structure_drop.reset()
             self.structure_page_chooser.reset()
+            self.sort_selector.reset()
 
     def _uses_new_structure_features(self) -> bool:
         """Check whether self.database_version is >= v1.0.0-rc.2"""
@@ -425,8 +483,8 @@ class OptimadeQueryFilterWidget(  # pylint: disable=too-many-instance-attributes
         optimade_filter = self.filters.collect_value()
         optimade_filter = (
             "( {} ) AND ( {} )".format(optimade_filter, add_to_filter)
-            if optimade_filter
-            else add_to_filter
+            if optimade_filter and add_to_filter
+            else optimade_filter or add_to_filter or None
         )
         LOGGER.debug("Querying with filter: %s", optimade_filter)
 
@@ -437,6 +495,7 @@ class OptimadeQueryFilterWidget(  # pylint: disable=too-many-instance-attributes
             "page_limit": self.page_limit,
             "page_offset": self.offset,
             "page_number": self.number,
+            "sort": self.sorting,
         }
         LOGGER.debug(
             "Parameters (excluding filter) sent to query util func: %s",
@@ -445,12 +504,21 @@ class OptimadeQueryFilterWidget(  # pylint: disable=too-many-instance-attributes
 
         return perform_optimade_query(**queries)
 
+    @staticmethod
+    def _check_species_mass(structure: dict) -> dict:
+        """Ensure species.mass is using OPTIMADE API v1.0.1 type"""
+        if structure.get("species", False):
+            for species in structure["species"] or []:
+                if not isinstance(species.get("mass", None), (list, type(None))):
+                    species.pop("mass", None)
+        return structure
+
     def _update_structures(self, data: list):
         """Update structures dropdown from response data"""
         structures = []
 
         for entry in data:
-            structure = Structure(entry)
+            structure = Structure(self._check_species_mass(entry))
 
             formula = structure.attributes.chemical_formula_descriptive
             if formula is None:
