@@ -215,6 +215,7 @@ class ProviderImplementationChooser(  # pylint: disable=too-many-instance-attrib
 
                     LOGGER.debug("Exclude child DBs: %r", exclude_child_dbs)
                     data_returned -= len(exclude_child_dbs)
+                    data_available -= len(exclude_child_dbs)
                     if exclude_child_dbs and data_returned:
                         child_dbs, links, data_returned, _ = self._query(
                             exclude_ids=exclude_child_dbs
@@ -444,7 +445,9 @@ class ProviderImplementationChooser(  # pylint: disable=too-many-instance-attrib
         if link is not None:
             try:
                 if exclude_ids:
-                    filter_value = " AND ".join([f'id!="{id_}"' for id_ in exclude_ids])
+                    filter_value = " AND ".join(
+                        [f'NOT id="{id_}"' for id_ in exclude_ids]
+                    )
 
                     parsed_url = urllib.parse.urlparse(link)
                     queries = urllib.parse.parse_qs(parsed_url.query)
@@ -492,11 +495,11 @@ class ProviderImplementationChooser(  # pylint: disable=too-many-instance-attrib
                     }
                 }
         else:
-            filter_ = "link_type=child OR type=child"
+            filter_ = "( link_type=child OR type=child )"
             if exclude_ids:
                 filter_ += (
                     " AND ( "
-                    + " AND ".join([f'id!="{id_}"' for id_ in exclude_ids])
+                    + " AND ".join([f'NOT id="{id_}"' for id_ in exclude_ids])
                     + " )"
                 )
 
