@@ -30,7 +30,14 @@ from optimade_client.logger import LOGGER
 
 
 # Supported OPTIMADE spec versions
-__optimade_version__ = ["1.0.0", "1.0.0-rc.2", "1.0.0-rc.1", "0.10.1", "0.10.0"]
+__optimade_version__ = [
+    "1.0.1",
+    "1.0.0",
+    "1.0.0-rc.2",
+    "1.0.0-rc.1",
+    "0.10.1",
+    "0.10.0",
+]
 
 TIMEOUT_SECONDS = 10  # Seconds before URL query timeout is raised
 
@@ -325,18 +332,15 @@ def get_versioned_base_url(  # pylint: disable=too-many-branches
                 for key, value in zip(keys, values):
                     versions[key].append(value)
 
-            if versions.get("version", []):
-                for version in versions:
-                    version_path = f"/v{version}"
-                    if version_path in VERSION_PARTS:
-                        LOGGER.debug(
-                            "Found versioned base URL through /versions endpoint."
-                        )
-                        return (
-                            base_url + version_path[1:]
-                            if base_url.endswith("/")
-                            else base_url + version_path
-                        )
+            for version in versions.get("version", []):
+                version_path = f"/v{version}"
+                if version_path in VERSION_PARTS:
+                    LOGGER.debug("Found versioned base URL through /versions endpoint.")
+                    return (
+                        base_url + version_path[1:]
+                        if base_url.endswith("/")
+                        else base_url + version_path
+                    )
 
     timeout_seconds = 5  # Use custom timeout seconds due to potentially many requests
 
